@@ -1,6 +1,12 @@
 #!/usr/bin/perl -W -T
 use strict;
 
+#sub AUTOLOAD {
+#	print STDERR 'Hallo Welt.';
+#}
+BEGIN { $Package::Transporter::Package::OVERWRITE = 1;
+	$Package::Transporter::Package::DEBUG = 1; }
+
 use Package::Transporter sub{eval shift}, sub {
 	$_[0]->register_drain('::Flatened', 'FOR_ANY', 'IS_',
 		TRUE => 1, FALSE => 0);
@@ -10,7 +16,12 @@ use Package::Transporter sub{eval shift}, sub {
 	$_[0]->register_potential($yn, 'FOR_ANY', 'yn');
 };
 
+sub AUTOLOAD {
+	print STDERR 'Hallo Welt.';
+}
+
 print STDOUT ((IS_TRUE == 1) ? 'Ok' : 'Disorder'), "\n";
+#print STDOUT hallo_welt();
 
 package Synopsis;
 use Package::Transporter sub{eval shift}, sub {
@@ -54,4 +65,4 @@ yn(!defined(&sisponyS::Desc2::salut_monde));
 yn(!defined(&Synopsis::Desc1::salut_monde));
 yn(defined(&Synopsis::salut_monde));
 
-exit(0);
\ No newline at end of file
+exit(0);
